==> radauth-0.4.tar.gz: radauth-0.4/radauth.c <==
#include<stdio.h>
#include<string.h>
#include<mysql.h>
#include "conf.h"

char *clearSpaces();

int main(int argc, char *argv[]) {

	MYSQL mysql;
	MYSQL_RES *result;
	MYSQL_ROW row;

	char *salt;
	char *passwd;
	char *encpass;
	char *command;
	int con;
	int command_length;
        char *username;
        char *truncated;

        username = (char *) malloc((strlen(argv[1])*2));
	truncated = (char *) malloc((strlen(argv[1])*2));

        strcpy(username, argv[1]);
        strcpy(truncated, clearSpaces(username));
	free(username);


	if ( !argv[2] ) {
	   argv[2] = getenv("Password");
	   if ( !argv[2] ) {
		char *chap;
		char *challenge;
		chap = getenv("CHAP-Password");
		challenge = getenv("CHAP-Challenge");
		if ( chap ) {
			printf("Recieved a CHAP Password: %s with CHAP-Challenge: %s", chap, challenge);
			free(truncated);
			exit(1);
		} else {
	   		printf("No password was specified\n");
			free(truncated);
	   		exit(1);
		}
	   }
	}

	mysql_init(&mysql);

	if(!mysql_real_connect(&mysql,DBHOST,DBUSER,DBPASS,DBBASE,0,NULL,0)) {
		printf("Error Connecting To Database\n");
		exit(1);
	}

	command_length = strlen(SELECT_PASSWD) + strlen(truncated);
	command = (char *) malloc(command_length*sizeof(char));
	sprintf(command,SELECT_PASSWD,truncated);

	con = mysql_query(&mysql, command);
	free(command);
	result = mysql_store_result(&mysql);
	row = mysql_fetch_row(result);

	if ( !row ) {
		fprintf(stdout, "User '%s' does not exist\n", truncated);
		exit(1);
	}

	mysql_free_result(result);
	mysql_close(&mysql);

	passwd = (char *) malloc((strlen(row[0])*sizeof(char)));

	if ( !passwd ) {
		fprintf(stdout, "Failed to alocate memory\n");
		free(truncated);
		exit(1);
	}

	strcpy(passwd, row[0]);

	salt = (char *) malloc(2*sizeof(char));
	encpass = (char *) malloc(14*sizeof(char));
	strncpy(salt, passwd, 2);
	salt[2] = '\0';
	encpass = (char *) crypt(argv[2], salt);

	if(strcmp(encpass,passwd) == 0) {
		printf("Auth ok.\n");
		free(truncated);
		exit(0);
	} else {
		printf("Bad auth.\n");
		free(truncated);
		exit(1);
	}
}

char *clearSpaces(char *username) {

        char a[42];
        char *b;
        char * pch;

        strcpy(a, username);

        b = a;

        while ( *b == ' ' || *b == '"') {
                b++;
        }

        pch = strchr(b, '"');

        if (pch != NULL) {
                int thisnum;
		char *c;
                thisnum = pch-b;
                c = (char *) malloc((strlen(b)*sizeof(char)));
                strncpy(c, b, thisnum);
                return c;
        } else {
                return b;
        }
}

==> radauth-0.5.tar.gz: radauth-0.5/radauth.c <==
#include<stdio.h>
#include<string.h>
#include<mysql.h>
#include "conf.h"
#include "trim.h"

int main(int argc, char *argv[]) {

	MYSQL mysql;
	MYSQL_RES *result;
	MYSQL_ROW row;

	char *salt;
	char *passwd;
	char *encpass;
	char *command;
	int con;
	int command_length;
   char *username;
   char *truncated;

   username = (char *) malloc((strlen(argv[1])*2));
	truncated = (char *) malloc((strlen(argv[1])*2));

   strcpy(username, argv[1]);
   strcpy(truncated, clearSpaces(username));
	free(username);


	if ( !argv[2] ) {
	   argv[2] = getenv("Password");
	   if ( !argv[2] ) {
		char *chap;
		char *challenge;
		chap = getenv("CHAP-Password");
		challenge = getenv("CHAP-Challenge");
		if ( chap ) {
			printf("Received a CHAP Password: %s with CHAP-Challenge: %s", chap, challenge);
			free(truncated);
			exit(1);
		} else {
	   	printf("No password was specified\n");
			free(truncated);
	   	exit(1);
		}
	   }
	}

	mysql_init(&mysql);

	if(!mysql_real_connect(&mysql,DBHOST,DBUSER,DBPASS,DBBASE,0,NULL,0)) {
		printf("Error Connecting To Database\n");
		exit(1);
	}

	command_length = strlen(SELECT_PASSWD) + strlen(truncated);
	command = (char *) malloc(command_length*sizeof(char));
	sprintf(command,SELECT_PASSWD,truncated);

	con = mysql_query(&mysql, command);
	free(command);
	result = mysql_store_result(&mysql);
	row = mysql_fetch_row(result);

	if ( !row ) {
		fprintf(stdout, "User '%s' does not exist\n", truncated);
		exit(1);
	}

	mysql_free_result(result);
	mysql_close(&mysql);

	passwd = (char *) malloc((strlen(row[0])*sizeof(char)));

	if ( !passwd ) {
		fprintf(stdout, "Failed to alocate memory\n");
		free(truncated);
		exit(1);
	}

	strcpy(passwd, row[0]);

#ifdef CRYPT

	salt = (char *) malloc(2*sizeof(char));
	encpass = (char *) malloc(14*sizeof(char));
	strncpy(salt, passwd, 2);
	salt[2] = '\0';
	encpass = (char *) crypt(argv[2], salt);

	if(strcmp(encpass,passwd) == 0) {

#else

	if(strcmp(argv[2], passwd) == 0) {

#endif
			  
		printf("Auth ok.\n");
		free(truncated);
		exit(0);
	} else {
		printf("Bad auth.\n");
		free(truncated);
		exit(1);
	}
}
